macro_rules! checked_as {
($value:expr, $target_type:ty) => { ... };
}Expand description
A helper macro for performing a checked cast from one type to another, returning a ExecutionError invariant violation if the cast fails.
macro_rules! checked_as {
($value:expr, $target_type:ty) => { ... };
}A helper macro for performing a checked cast from one type to another, returning a ExecutionError invariant violation if the cast fails.